package com.goldenwater.slaj.ttsa.service;

import java.util.List;
import com.goldenwater.slaj.ttsa.domain.BisTtsaCeriExtApll;

public interface IBisTtsaCeriExtApllService {
    BisTtsaCeriExtApll selectBisTtsaCeriExtApllByGuid(String guid);
    List<BisTtsaCeriExtApll> selectBisTtsaCeriExtApllList(BisTtsaCeriExtApll bisTtsaCeriExtApll);
    int insertBisTtsaCeriExtApll(BisTtsaCeriExtApll bisTtsaCeriExtApll);
    int updateBisTtsaCeriExtApll(BisTtsaCeriExtApll bisTtsaCeriExtApll);
    int deleteBisTtsaCeriExtApllByGuid(String guid);
    int deleteBisTtsaCeriExtApllByGuids(String[] guids);
}
